atomate.feff package — atomate 0.9.2 documentation

# atomate.feff package

## Subpackages

- atomate.feff.firetasks package
  - Subpackages
    - atomate.feff.firetasks.tests package
      - Submodules
      - atomate.feff.firetasks.tests.test_tasks module
      - Module contents
  - Submodules
  - atomate.feff.firetasks.glue_tasks module
  - atomate.feff.firetasks.parse_outputs module
  - atomate.feff.firetasks.run_calc module
  - atomate.feff.firetasks.write_inputs module
  - Module contents
- atomate.feff.fireworks package
  - Subpackages
    - atomate.feff.fireworks.tests package
      - Submodules
      - atomate.feff.fireworks.tests.test_fireworks module
      - Module contents
  - Submodules
  - atomate.feff.fireworks.core module
  - Module contents
- atomate.feff.workflows package
  - Subpackages
    - atomate.feff.workflows.tests package
      - Submodules
      - atomate.feff.workflows.tests.test_eels_workflows module
      - atomate.feff.workflows.tests.test_exafs_scattering_paths module
      - atomate.feff.workflows.tests.test_xas_workflows module
      - Module contents
  - Submodules
  - atomate.feff.workflows.core module
  - atomate.feff.workflows.presets module
  - Module contents

## Submodules

## atomate.feff.database module

class `atomate.feff.database.` `FeffCalcDb`(host='localhost', port=27017, database='feff', collection='tasks', user=None, password=None, **kwargs)

  Bases: `atomate.utils.database.CalcDb`

  `__init__`(host='localhost', port=27017, database='feff', collection='tasks', user=None, password=None, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  `build_indexes`(indexes=None, background=True)

    Build the indexes.

    Args:

      indexes (list): list of single field indexes to be built. background (bool): Run in the background or not.

  `reset`()

## Module contents